@@ -292,6 +292,10 @@ class MultiGMPE(GMPE):
                             vs30max = float(v[1])
                             sites.vs30 = np.clip(sites.vs30, vs30min, vs30max)
                             addDepthParameters(sites)
+                        elif k == "ztor":
+                            ztor_min = float(v[0])
+                            ztor_max = float(v[1])
+                            rup.ztor = np.clip(rup.ztor, ztor_min, ztor_max)
 
             # -----------------------------------------------------------------
             # Evaluate
